@@ -43,6 +43,7 @@ function Print(guiAction, document, view) {
 
 Print.prototype = new File();
 
+
 Print.defaultPrinter = undefined;
 
 Print.getDefaultPrinter = function() {
@@ -52,6 +53,10 @@ Print.getDefaultPrinter = function() {
     return Print.defaultPrinter;
 };
 
+Print.setProxy = function(p) {
+    Print.proxy = p;
+};
+
 Print.prototype.beginEvent = function() {
     File.prototype.beginEvent.call(this);
 
@@ -110,15 +115,18 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
     }
 
-    var paperSizeEnum = Print.getPaperSizeEnum(this.document);
-    if (paperSizeEnum!==QPrinter.Custom) {
-        printer.setPaperSize(paperSizeEnum);
-    }
-    else {
+    // QPrinter.Custom is deprecated / undefined:
+//    var paperSizeEnum = Print.getPaperSizeEnum(this.document);
+//    if (paperSizeEnum!==QPrinter.Custom) {
+//        printer.setPaperSize(paperSizeEnum);
+//    }
+//    else {
         //printer.setPaperSize(QPrinter.Custom);
+
+        // always use custom page size to work around Qt page size limitations:
         var paperSizeMM = Print.getPaperSizeMM(this.document);
         printer.setPaperSize(paperSizeMM, QPrinter.Millimeter);
-    }
+//    }
     printer.setFullPage(true);
     printer.setOrientation(Print.getPageOrientationEnum(this.document));
 
@@ -171,7 +179,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
                 Print.printDialog.open(this, "dummy");
             }
 
-            // Mac OS X, Linux, various other unices:
+            // macOS, Linux, various other unices:
             else {
                 Print.printDialog.exec();
             }
@@ -194,6 +202,12 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
  * \param printer QPrinter object or undefined to create on the fly.
  */
 Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
+    // make sure selected entities are not printed with selection color:
+    var di = EAction.getDocumentInterface();
+    if (!isNull(di)) {
+        di.deselectAll();
+    }
+
     var printer = this.createPrinter(pdfFile, printerName, pdfVersion);
     if (isNull(printer)) {
         qWarning("Print.prototype.print: no printer created");
@@ -206,7 +220,12 @@ Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
         return false;
     }
 
-    this.printCurrentBlock(printer, painter);
+    //for (var i=1; i<=printer.copyCount(); i++) {
+        //if (i>1) {
+        //    printer.newPage();
+        //}
+        this.printCurrentBlock(printer, painter);
+    //}
 
     painter.end();
     printer.destroy();
@@ -284,8 +303,24 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     // iterate through all pages and print the appropriate area
     var firstPage = true;
 
+    var fromPage = printer.fromPage();
+    var toPage = printer.toPage();
+
     var pages = Print.getPages(this.document);
     for (var i = 0; i < pages.length; ++i) {
+
+        if (fromPage!==0) {
+            if (i+1<fromPage) {
+                continue;
+            }
+        }
+
+        if (toPage!==0) {
+            if (i+1>toPage) {
+                continue;
+            }
+        }
+
         // if this is not the first page, add new page:
         if (!firstPage) {
             printer.newPage();
@@ -355,6 +390,10 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
         if (Print.getEnablePageTags(this.document)) {
             Print.drawPageTags(this.document, painter, i, pageBorderTransformed, true, printerFactor);
         }
+
+        if (Print.hasFooter(this.document)) {
+            Print.drawPageFooter(this.document, painter, i, pageBorderTransformed, true, printerFactor);
+        }
     }
 
     this.scene.setPixelSizeHint(previousPixelSizeHint);
@@ -416,12 +455,25 @@ Print.getPaperBox = function(document) {
 
 /**
  * Auto fit drawing to page size.
+ * \param ori: True: auto set page orientation
  */
-Print.autoFitDrawing = function(di) {
+Print.autoFitDrawing = function(di, ori) {
+    if (isNull(ori)) {
+        ori = false;
+    }
+
     var document = di.getDocument();
     // drawing bounding box in drawing units:
     var bBox = document.getBoundingBox(true, true);
     //qDebug("bb: ", bBox);
+    if (ori) {
+        if (bBox.getWidth()>bBox.getHeight()) {
+            Print.setPageOrientationEnum(di, QPrinter.Landscape);
+        }
+        else {
+            Print.setPageOrientationEnum(di, QPrinter.Portrait);
+        }
+    }
     Print.autoFitBox(di, bBox);
     Print.centerBox(di, bBox);
 };
@@ -515,6 +567,14 @@ Print.centerBox = function(di, bBox) {
  * \param painter QPainter object if we are printing, RPainterPath for print preview.
  */
 Print.drawCropMarks = function(document, painter, border, printing) {
+    var isPainter = isFunction(painter.drawLinesF);
+
+    var clipping = false;
+    if (isPainter) {
+        clipping = painter.hasClipping();
+        painter.setClipping(false);
+    }
+
     var scale = Print.getScale(document);
     var offset = Print.getOffset(document);
     var unitScale = Print.getUnitScale(document);
@@ -542,7 +602,7 @@ Print.drawCropMarks = function(document, painter, border, printing) {
 
 
     // printing:
-    if (isFunction(painter.drawLinesF)) {
+    if (isPainter) {
         for (var k=0; k<lines.length; ++k) {
             lines[k].translate(-offset.x, -offset.y);
         }
@@ -557,6 +617,9 @@ Print.drawCropMarks = function(document, painter, border, printing) {
         }
     }
 
+    if (isPainter) {
+        painter.setClipping(clipping);
+    }
 };
 
 /**
@@ -720,7 +783,20 @@ Print.drawPageTags = function(document, painter, index, border, printing, printe
     else {
         painter.addPath(new RPainterPath(path));
     }
+};
 
+
+/**
+ * Draws the page footer for printing (black, small, border area).
+ * \param index page index
+ * \param border page border geometry of the page
+ * \param painter QPainter object if we are printing, RTextData for print preview.
+ * \param printerFactor Factor from Millimeter to printer unit.
+ */
+Print.drawPageFooter = function(document, painterOrText, index, border, printing, printerFactor) {
+    if (!isNull(Print.proxy)) {
+        Print.proxy.drawPageFooter(document, painterOrText, index, border, printing, printerFactor);
+    }
 };
 
 /**
@@ -1011,7 +1087,11 @@ Print.getGlueMarginLeft = function(document) {
 
 Print.getDefaultPrintMarginLeft = function(document, paperUnit) {
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return pageRect.left().toFixed(4);
+    var ret = parseFloat(pageRect.left().toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginTop = function(document) {
@@ -1020,7 +1100,11 @@ Print.getGlueMarginTop = function(document) {
 
 Print.getDefaultPrintMarginTop = function(document, paperUnit) {
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return pageRect.top().toFixed(4);
+    var ret = parseFloat(pageRect.top().toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginRight = function(document) {
@@ -1030,7 +1114,11 @@ Print.getGlueMarginRight = function(document) {
 Print.getDefaultPrintMarginRight = function(document, paperUnit) {
     var paperRect = Print.getDefaultPaperRect(document, paperUnit);
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return (paperRect.right() - pageRect.right()).toFixed(4);
+    var ret = parseFloat((paperRect.right() - pageRect.right()).toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getGlueMarginBottom = function(document) {
@@ -1040,7 +1128,11 @@ Print.getGlueMarginBottom = function(document) {
 Print.getDefaultPrintMarginBottom = function(document, paperUnit) {
     var paperRect = Print.getDefaultPaperRect(document, paperUnit);
     var pageRect = Print.getDefaultPageRect(document, paperUnit);
-    return (paperRect.bottom() - pageRect.bottom()).toFixed(4);
+    var ret = parseFloat((paperRect.bottom() - pageRect.bottom()).toFixed(4));
+    if (!isNumber(ret)) {
+        return 0.0;
+    }
+    return ret;
 };
 
 Print.getOffset = function(document) {
@@ -1160,7 +1252,7 @@ Print.getPaperSizeEnum = function(document) {
         }
     }
 
-    return QPrinter.Custom;
+    return undefined;
 };
 
 /**
@@ -1413,6 +1505,10 @@ Print.getEnablePageTags = function(document) {
     return Print.getBoolValue("PageTagSettings/EnablePageTags", false, document);
 };
 
+Print.hasFooter = function(document) {
+    return Print.getIntValue("FooterSettings/Footer", 0, document) > 0;
+};
+
 //Print.getIdentifyPageTags = function(document) {
 //    return Print.getBoolValue("PageTagSettings/IdentifyPageTags", false, document);
 //};
@@ -1441,6 +1537,27 @@ Print.getTagAlignment = function(document) {
     return Print.getValue("PageTagSettings/TagAlignment", "Inside", document);
 };
 
+Print.getFooterPosition = function(document) {
+    return Print.getValue("FooterSettings/FooterPosition", "TopLeft", document);
+};
+
+Print.getFooterFont = function(document) {
+    var ret = Print.getValue("FooterSettings/FooterFont", new QFont(), document);
+    if (isOfType(ret, QFont)) {
+        return ret;
+    }
+
+    if (isString(ret)) {
+        var f = new QFont();
+        f.fromString(ret);
+        return f;
+    }
+
+    qWarning("FooterFont is not a valid font");
+    return new QFont();
+};
+
+
 /**
  * Parses the given scale string (e.g. "1:2") and returns the scale as number (e.g. 0.5).
  */
