@@ -19,7 +19,7 @@
 
  
 include("scripts/File/File.js");
-include("../AutoSave/AutoSave.js");
+include("scripts/File/AutoSave/AutoSave.js");
 
 /**
  * This action handles all user interaction to save the current drawing. If the current
@@ -86,7 +86,7 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
 
     if (overwriteWarning) {
         if (new QFileInfo(fileName).exists()) {
-            buttons = new QMessageBox.StandardButtons(QMessageBox.Yes, QMessageBox.No);
+            buttons = makeQMessageBoxStandardButtons(QMessageBox.Yes, QMessageBox.No);
             ret = QMessageBox.warning(
                         appWin,
                         qsTr("Overwrite File?"),
