@@ -116,7 +116,13 @@ function getTypeOf(v) {
  * derived from QWidget.
  */
 function isOfType(obj, type) {
-    return !isNull(obj) && obj.constructor===type;
+    if (RSettings.getQtVersion() < 0x060000) {
+        return !isNull(obj) && obj.constructor===type;
+    }
+    else {
+        //return !isNull(obj) && (obj.constructor===type || (isFunction(obj.getType) && obj.getType()===type.getType()));
+        return !isNull(obj) && isFunction(obj.getType) && obj.getType()===type.getType();
+    }
 }
 
 /**
@@ -144,8 +150,13 @@ function isNull(obj) {
         return true;
     }
 
-    return (obj==null ||
-            (typeof(obj.isNull)==="function" && obj.isNull()===true));
+    return (
+        obj==null ||
+        // wrapped object is NULL:
+        (typeof(obj.isNullWrapper)==="function" && obj.isNullWrapper()===true) ||
+        // shared pointer is NULL:
+        (typeof(obj.data)==="function" && typeof(obj.isNull)==="function" && obj.isNull()===true)
+    );
 }
 
 /**
@@ -260,7 +271,12 @@ function isSeparator(obj) {
  * \return true if the given object is a layer.
  */
 function isLayer(obj) {
-    return isOfType(obj, RLayer) || isOfType(obj, RLayerPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLayer) || isOfType(obj, RLayerPointer);
+    }
+    else {
+        return isOfType(obj, RLayer);
+    }
 }
 
 /**
@@ -269,7 +285,12 @@ function isLayer(obj) {
  * \return true if the given object is a block.
  */
 function isBlock(obj) {
-    return isOfType(obj, RBlock) || isOfType(obj, RBlockPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RBlock) || isOfType(obj, RBlockPointer);
+    }
+    else {
+        return isOfType(obj, RBlock);
+    }
 }
 
 /**
@@ -278,7 +299,12 @@ function isBlock(obj) {
  * \return true if the given object is a layout.
  */
 function isLayout(obj) {
-    return isOfType(obj, RLayout) || isOfType(obj, RLayoutPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLayout) || isOfType(obj, RLayoutPointer);
+    }
+    else {
+        return isOfType(obj, RLayout);
+    }
 }
 
 /**
@@ -328,7 +354,12 @@ function isDimensionEntity(obj) {
  * (RDimDiametricEntity).
  */
 function isDimDiametricEntity(obj) {
-    return isOfType(obj, RDimDiametricEntity) || isOfType(obj, RDimDiametricEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimDiametricEntity) || isOfType(obj, RDimDiametricEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimDiametricEntity);
+    }
 }
 
 /**
@@ -338,7 +369,12 @@ function isDimDiametricEntity(obj) {
  * (RDimAlignedEntity).
  */
 function isDimAlignedEntity(obj) {
-    return isOfType(obj, RDimAlignedEntity) || isOfType(obj, RDimAlignedEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAlignedEntity) || isOfType(obj, RDimAlignedEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAlignedEntity);
+    }
 }
 
 /**
@@ -348,7 +384,12 @@ function isDimAlignedEntity(obj) {
  * (RDimRotatedEntity).
  */
 function isDimRotatedEntity(obj) {
-    return isOfType(obj, RDimRotatedEntity) || isOfType(obj, RDimRotatedEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimRotatedEntity) || isOfType(obj, RDimRotatedEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimRotatedEntity);
+    }
 }
 
 /**
@@ -358,7 +399,12 @@ function isDimRotatedEntity(obj) {
  * (RDimOrdinateEntity).
  */
 function isDimOrdinateEntity(obj) {
-    return isOfType(obj, RDimOrdinateEntity) || isOfType(obj, RDimOrdinateEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimOrdinateEntity) || isOfType(obj, RDimOrdinateEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimOrdinateEntity);
+    }
 }
 
 /**
@@ -368,7 +414,12 @@ function isDimOrdinateEntity(obj) {
  * (RDimRadialEntity).
  */
 function isDimRadialEntity(obj) {
-    return isOfType(obj, RDimRadialEntity) || isOfType(obj, RDimRadialEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimRadialEntity) || isOfType(obj, RDimRadialEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimRadialEntity);
+    }
 }
 
 /**
@@ -388,7 +439,12 @@ function isDimAngularEntity(obj) {
  * (RDimAngular2LEntity).
  */
 function isDimAngular2LEntity(obj) {
-    return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAngular2LEntity);
+    }
 }
 
 /**
@@ -398,7 +454,12 @@ function isDimAngular2LEntity(obj) {
  * (RDimAngular3PEntity).
  */
 function isDimAngular3PEntity(obj) {
-    return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimAngular3PEntity);
+    }
 }
 
 /**
@@ -408,7 +469,12 @@ function isDimAngular3PEntity(obj) {
  * (RDimArcLengthEntity).
  */
 function isDimArcLengthEntity(obj) {
-    return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimArcLengthEntity);
+    }
 }
 
 /**
@@ -418,7 +484,12 @@ function isDimArcLengthEntity(obj) {
  * (RDimLinearEntity).
  */
 function isDimLinearEntity(obj) {
-    return isOfType(obj, RDimLinearEntity) || isOfType(obj, RDimLinearEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RDimLinearEntity) || isOfType(obj, RDimLinearEntityPointer);
+    }
+    else {
+        return isOfType(obj, RDimLinearEntity);
+    }
 }
 
 /**
@@ -427,7 +498,12 @@ function isDimLinearEntity(obj) {
  * \return true if the given object is an arc entity (RHatchEntity).
  */
 function isHatchEntity(obj) {
-    return isOfType(obj, RHatchEntity) || isOfType(obj, RHatchEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RHatchEntity) || isOfType(obj, RHatchEntityPointer);
+    }
+    else {
+        return isOfType(obj, RHatchEntity);
+    }
 }
 
 /**
@@ -436,7 +512,12 @@ function isHatchEntity(obj) {
  * \return true if the given object is an arc entity (RArcEntity).
  */
 function isArcEntity(obj) {
-    return isOfType(obj, RArcEntity) || isOfType(obj, RArcEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RArcEntity) || isOfType(obj, RArcEntityPointer);
+    }
+    else {
+        return isOfType(obj, RArcEntity);
+    }
 }
 
 /**
@@ -445,7 +526,12 @@ function isArcEntity(obj) {
  * \return true if the given object is a line entity (RCircleEntity).
  */
 function isCircleEntity(obj) {
-    return isOfType(obj, RCircleEntity) || isOfType(obj, RCircleEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RCircleEntity) || isOfType(obj, RCircleEntityPointer);
+    }
+    else {
+        return isOfType(obj, RCircleEntity);
+    }
 }
 
 /**
@@ -454,7 +540,12 @@ function isCircleEntity(obj) {
  * \return true if the given object is an ellipse entity (REllipseEntity).
  */
 function isEllipseEntity(obj) {
-    return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
+    }
+    else {
+        return isOfType(obj, REllipseEntity);
+    }
 }
 
 /**
@@ -481,7 +572,12 @@ function isFullEllipseEntity(obj) {
  * \return true if the given object is a line entity (RLineEntity).
  */
 function isLineEntity(obj) {
-    return isOfType(obj, RLineEntity) || isOfType(obj, RLineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLineEntity) || isOfType(obj, RLineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RLineEntity);
+    }
 }
 
 /**
@@ -499,7 +595,12 @@ function isLineBasedEntity(obj) {
  * \return true if the given object is an xline entity (RXLineEntity).
  */
 function isXLineEntity(obj) {
-    return isOfType(obj, RXLineEntity) || isOfType(obj, RXLineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RXLineEntity) || isOfType(obj, RXLineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RXLineEntity);
+    }
 }
 
 /**
@@ -508,7 +609,12 @@ function isXLineEntity(obj) {
  * \return true if the given object is a ray entity (RRayEntity).
  */
 function isRayEntity(obj) {
-    return isOfType(obj, RRayEntity) || isOfType(obj, RRayEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RRayEntity) || isOfType(obj, RRayEntityPointer);
+    }
+    else {
+        return isOfType(obj, RRayEntity);
+    }
 }
 
 /**
@@ -517,7 +623,12 @@ function isRayEntity(obj) {
  * \return true if the given object is a point entity (RPointEntity).
  */
 function isPointEntity(obj) {
-    return isOfType(obj, RPointEntity) || isOfType(obj, RPointEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPointEntity) || isOfType(obj, RPointEntityPointer);
+    }
+    else {
+        return isOfType(obj, RPointEntity);
+    }
 }
 
 /**
@@ -526,14 +637,24 @@ function isPointEntity(obj) {
  * \return true if the given object is an image entity (RImageEntity).
  */
 function isImageEntity(obj) {
-    return isOfType(obj, RImageEntity) || isOfType(obj, RImageEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RImageEntity) || isOfType(obj, RImageEntityPointer);
+    }
+    else {
+        return isOfType(obj, RImageEntity);
+    }
 }
 
 /**
  * \return true if the given object is a polyline entity (RPolylineEntity).
  */
 function isPolylineEntity(obj) {
-    return isOfType(obj, RPolylineEntity) || isOfType(obj, RPolylineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPolylineEntity) || isOfType(obj, RPolylineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RPolylineEntity);
+    }
 }
 
 /**
@@ -566,7 +687,12 @@ function isOpenPolylineEntity(obj, tolerance) {
  * \return true if the given object is a solid entity (RSolidEntity).
  */
 function isSolidEntity(obj) {
-    return isOfType(obj, RSolidEntity) || isOfType(obj, RSolidEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSolidEntity) || isOfType(obj, RSolidEntityPointer);
+    }
+    else {
+        return isOfType(obj, RSolidEntity);
+    }
 }
 
 /**
@@ -575,7 +701,12 @@ function isSolidEntity(obj) {
  * \return true if the given object is a trace entity (RTraceEntity).
  */
 function isTraceEntity(obj) {
-    return isOfType(obj, RTraceEntity) || isOfType(obj, RTraceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTraceEntity) || isOfType(obj, RTraceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RTraceEntity);
+    }
 }
 
 /**
@@ -584,7 +715,12 @@ function isTraceEntity(obj) {
  * \return true if the given object is a face entity (RFaceEntity).
  */
 function isFaceEntity(obj) {
-    return isOfType(obj, RFaceEntity) || isOfType(obj, RFaceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RFaceEntity) || isOfType(obj, RFaceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RFaceEntity);
+    }
 }
 
 /**
@@ -593,7 +729,12 @@ function isFaceEntity(obj) {
  * \return true if the given object is a viewport entity (RViewportEntity).
  */
 function isViewportEntity(obj) {
-    return isOfType(obj, RViewportEntity) || isOfType(obj, RViewportEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RViewportEntity) || isOfType(obj, RViewportEntityPointer);
+    }
+    else {
+        return isOfType(obj, RViewportEntity);
+    }
 }
 
 /**
@@ -602,7 +743,12 @@ function isViewportEntity(obj) {
  * \return true if the given object is a spline entity (RSplineEntity).
  */
 function isSplineEntity(obj) {
-    return isOfType(obj, RSplineEntity) || isOfType(obj, RSplineEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSplineEntity) || isOfType(obj, RSplineEntityPointer);
+    }
+    else {
+        return isOfType(obj, RSplineEntity);
+    }
 }
 
 /**
@@ -638,7 +784,12 @@ function isTextBasedEntity(obj) {
  * \return true if the given object is a text entity (RTextEntity).
  */
 function isTextEntity(obj) {
-    return isOfType(obj, RTextEntity) || isOfType(obj, RTextEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTextEntity) || isOfType(obj, RTextEntityPointer);
+    }
+    else {
+        return isOfType(obj, RTextEntity);
+    }
 }
 
 /**
@@ -656,7 +807,12 @@ function isSimpleTextEntity(obj) {
  * \return true if the given object is a block reference entity (RBlockReferenceEntity).
  */
 function isBlockReferenceEntity(obj) {
-    return isOfType(obj, RBlockReferenceEntity) || isOfType(obj, RBlockReferenceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RBlockReferenceEntity) || isOfType(obj, RBlockReferenceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RBlockReferenceEntity);
+    }
 }
 
 /**
@@ -665,7 +821,12 @@ function isBlockReferenceEntity(obj) {
  * \return true if the given object is an attribute definition entity (RAttributeDefinitionEntity).
  */
 function isAttributeDefinitionEntity(obj) {
-    return isOfType(obj, RAttributeDefinitionEntity) || isOfType(obj, RAttributeDefinitionEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RAttributeDefinitionEntity) || isOfType(obj, RAttributeDefinitionEntityPointer);
+    }
+    else {
+        return isOfType(obj, RAttributeDefinitionEntity);
+    }
 }
 
 /**
@@ -674,7 +835,12 @@ function isAttributeDefinitionEntity(obj) {
  * \return true if the given object is an attribute entity (RAttributeEntity).
  */
 function isAttributeEntity(obj) {
-    return isOfType(obj, RAttributeEntity) || isOfType(obj, RAttributeEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RAttributeEntity) || isOfType(obj, RAttributeEntityPointer);
+    }
+    else {
+        return isOfType(obj, RAttributeEntity);
+    }
 }
 
 /**
@@ -684,7 +850,12 @@ function isAttributeEntity(obj) {
  * (RLeaderEntity).
  */
 function isLeaderEntity(obj) {
-    return isOfType(obj, RLeaderEntity) || isOfType(obj, RLeaderEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLeaderEntity) || isOfType(obj, RLeaderEntityPointer);
+    }
+    else {
+        return isOfType(obj, RLeaderEntity);
+    }
 }
 
 /**
@@ -693,7 +864,12 @@ function isLeaderEntity(obj) {
  * \return true if the given object is a tolerance entity (RToleranceEntity).
  */
 function isToleranceEntity(obj) {
-    return isOfType(obj, RToleranceEntity) || isOfType(obj, RToleranceEntityPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RToleranceEntity) || isOfType(obj, RToleranceEntityPointer);
+    }
+    else {
+        return isOfType(obj, RToleranceEntity);
+    }
 }
 
 /**
@@ -719,6 +895,10 @@ function isEntityType(obj, type) {
         }
     }
 
+    if (type===RS.EntityAll) {
+        return true;
+    }
+
     return false;
 }
 
@@ -748,7 +928,12 @@ function isDirectedShape(obj) {
  * \return true if the given object is an arc shape (RArc).
  */
 function isArcShape(obj) {
-    return isOfType(obj, RArc) || isOfType(obj, RArcPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RArc) || isOfType(obj, RArcPointer);
+    }
+    else {
+        return isOfType(obj, RArc);
+    }
 }
 
 /**
@@ -757,7 +942,12 @@ function isArcShape(obj) {
  * \return true if the given object is a circle shape (RCircle).
  */
 function isCircleShape(obj) {
-    return isOfType(obj, RCircle) || isOfType(obj, RCirclePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RCircle) || isOfType(obj, RCirclePointer);
+    }
+    else {
+        return isOfType(obj, RCircle);
+    }
 }
 
 /**
@@ -766,7 +956,12 @@ function isCircleShape(obj) {
  * \return true if the given object is an ellipse shape (REllipse).
  */
 function isEllipseShape(obj) {
-    return isOfType(obj, REllipse) || isOfType(obj, REllipsePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, REllipse) || isOfType(obj, REllipsePointer);
+    }
+    else {
+        return isOfType(obj, REllipse);
+    }
 }
 
 /**
@@ -802,7 +997,12 @@ function isLineBasedShape(obj) {
  * \return true if the given object is a line shape (RLine).
  */
 function isLineShape(obj) {
-    return isOfType(obj, RLine) || isOfType(obj, RLinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RLine) || isOfType(obj, RLinePointer);
+    }
+    else {
+        return isOfType(obj, RLine);
+    }
 }
 
 /**
@@ -811,7 +1011,12 @@ function isLineShape(obj) {
  * \return true if the given object is an xline shape (RXLine).
  */
 function isXLineShape(obj) {
-    return isOfType(obj, RXLine) || isOfType(obj, RXLinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RXLine) || isOfType(obj, RXLinePointer);
+    }
+    else {
+        return isOfType(obj, RXLine);
+    }
 }
 
 /**
@@ -820,7 +1025,12 @@ function isXLineShape(obj) {
  * \return true if the given object is a ray shape (RRay).
  */
 function isRayShape(obj) {
-    return isOfType(obj, RRay) || isOfType(obj, RRayPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RRay) || isOfType(obj, RRayPointer);
+    }
+    else {
+        return isOfType(obj, RRay);
+    }
 }
 
 /**
@@ -829,7 +1039,12 @@ function isRayShape(obj) {
  * \return true if the given object is a point shape (RPoint).
  */
 function isPointShape(obj) {
-    return isOfType(obj, RPoint) || isOfType(obj, RPointPointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPoint) || isOfType(obj, RPointPointer);
+    }
+    else {
+        return isOfType(obj, RPoint);
+    }
 }
 
 /**
@@ -838,7 +1053,12 @@ function isPointShape(obj) {
  * \return true if the given object is a polyline shape (RPolyline).
  */
 function isPolylineShape(obj) {
-    return isOfType(obj, RPolyline) || isOfType(obj, RPolylinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RPolyline) || isOfType(obj, RPolylinePointer);
+    }
+    else {
+        return isOfType(obj, RPolyline);
+    }
 }
 
 /**
@@ -854,7 +1074,12 @@ function isClosedPolylineShape(obj) {
  * \return true if the given object is a spline shape (RSpline).
  */
 function isSplineShape(obj) {
-    return isOfType(obj, RSpline) || isOfType(obj, RSplinePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RSpline) || isOfType(obj, RSplinePointer);
+    }
+    else {
+        return isOfType(obj, RSpline);
+    }
 }
 
 /**
@@ -877,7 +1102,12 @@ function isClosedSplineShape(obj, tolerance) {
  * \return true if the given object is a triangle shape (RTriangle).
  */
 function isTriangleShape(obj) {
-    return isOfType(obj, RTriangle) || isOfType(obj, RTrianglePointer);
+    if (RSettings.getQtVersion() < 0x060000) {
+        return isOfType(obj, RTriangle) || isOfType(obj, RTrianglePointer);
+    }
+    else {
+        return isOfType(obj, RTriangle);
+    }
 }
 
 /**
@@ -1354,8 +1584,8 @@ function copyDirectory(sourceDirPath, destDirPath) {
     var files;
     var srcName;
     var destName;
-    var filterFlags = new QDir.Filters(QDir.Files);
-    var sortFlags = new QDir.SortFlags(QDir.NoSort);
+    var filterFlags = makeQDirFilters(QDir.Files);
+    var sortFlags = makeQDirSortFlags(QDir.NoSort);
     files = sourceDir.entryList(filterFlags, sortFlags);
     for(i = 0; i< files.length; i++) {
         srcName = sourceDirPath + QDir.separator + files[i];
@@ -1365,7 +1595,7 @@ function copyDirectory(sourceDirPath, destDirPath) {
         }
     }
 
-    var flags = new QDir.Filters(QDir.AllDirs, QDir.NoDotAndDotDot);
+    var flags = makeQDirFilters(QDir.AllDirs, QDir.NoDotAndDotDot);
     files = sourceDir.entryList(flags);
     for(i = 0; i< files.length; i++) {
         srcName = sourceDirPath + QDir.separator + files[i];
@@ -1384,8 +1614,7 @@ function removeDirectory(dirPath) {
     var dir = new QDir(dirPath);
     var hasErr = false;
     if (dir.exists()) {
-        var flags = new QDir.Filters(QDir.NoDotAndDotDot, 
-                QDir.Dirs, QDir.Files, QDir.Hidden);
+        var flags = makeQDirFilters(QDir.NoDotAndDotDot, QDir.Dirs, QDir.Files, QDir.Hidden);
         var entries = dir.entryInfoList(flags);
         for (var i = 0; i <  entries.length; i++) {
             var entryInfo = entries[i];
@@ -1430,14 +1659,14 @@ function findFile(dirPath, fileName, ignoreDirs) {
     var i;
     var files;
     var name;
-    var filterFlags = new QDir.Filters(QDir.Files);
-    var sortFlags = new QDir.SortFlags(QDir.NoSort);
+    var filterFlags = makeQDirFilters(QDir.Files);
+    var sortFlags = makeQDirSortFlags(QDir.NoSort);
     files = dir.entryList([fileName], filterFlags, sortFlags);
     for (i=0; i<files.length; i++) {
         res = res.concat(dirPath + QDir.separator + files[i]);
     }
 
-    var flags = new QDir.Filters(QDir.AllDirs, QDir.NoDotAndDotDot);
+    var flags = makeQDirFilters(QDir.AllDirs, QDir.NoDotAndDotDot);
     files = dir.entryList(flags);
     for (i = 0; i< files.length; i++) {
         var nextDir = dirPath + QDir.separator + files[i];
@@ -1858,8 +2087,12 @@ String.prototype.trim = function() {
  */
 String.prototype.elidedText = function(font, pixel) {
     var fm = new QFontMetrics(font);
-    var t = fm.elidedText(this, Qt.ElideMiddle, pixel);
-    fm.destroy();
+    var s = this;
+    if (!isString(s)) {
+        s = s.toString();
+    }
+    var t = fm.elidedText(s, Qt.ElideMiddle, pixel);
+    destr(fm);
     // replace HORIZONTAL ELLIPSIS (not every GUI font has those):
     t = t.replace(/\u2026/g, '...');
     return t;
@@ -2806,6 +3039,16 @@ function applyTheme() {
     }
 }
 
+function setUtf8Codec(ts) {
+    if (RSettings.getQtVersion() >= 0x060000) {
+        ts.setEncoding(QStringConverter.Utf8);
+    }
+    else {
+        ts.setCodec("UTF-8");
+    }
+}
+
+
 function readTextFile(fileName) {
     var file = new QFile(fileName);
     var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
@@ -2876,7 +3119,8 @@ function createSpatialIndex() {
 
 // Qt 4 API workaround:
 function qsTranslate2(context, sourceText, disambiguation, n) {
-    if (RSettings.isQt(4)) {
+    // Qt 4:
+    if (RSettings.getQtVersion() < 0x050000) {
         if (isNull(disambiguation)) {
             return qsTranslate(context, sourceText);
         }
@@ -2885,6 +3129,8 @@ function qsTranslate2(context, sourceText, disambiguation, n) {
         }
         return qsTranslate(context, sourceText, disambiguation, "UnicodeUTF8", n);
     }
+
+    // Qt > 5
     return qsTranslate(context, sourceText, disambiguation, n);
 }
 
@@ -2906,6 +3152,36 @@ function makeQtMatchFlags() {
     return makeFlags.apply(this, argumentsNew);
 }
 
+function makeQtToolBarAreas() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.ToolBarAreas);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtWindowFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.WindowFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQtAlignment() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(Qt.Alignment);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQIODeviceOpenMode() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QIODevice.OpenMode);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeQMessageBoxStandardButtons() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QMessageBox.StandardButtons);
+    return makeFlags.apply(this, argumentsNew);
+}
+
 function makeFlags() {
     if (RSettings.isQt(6)) {
         var ret = 0;
